@@ -2,17 +2,17 @@
 Routines for converting PollyXT files to SCC files
 """
 
-from datetime import datetime, timedelta
+from datetime import timedelta
+from enum import Enum, IntEnum
 from pathlib import Path
 from typing import Tuple
-from enum import Enum, IntEnum
 
-from netCDF4 import Dataset
 import numpy as np
+from netCDF4 import Dataset
 
-from pollyxt_pipelines.polly_to_scc import pollyxt
-from pollyxt_pipelines.locations import Location
 from pollyxt_pipelines import utils
+from pollyxt_pipelines.locations import Location
+from pollyxt_pipelines.polly_to_scc import pollyxt
 from pollyxt_pipelines.polly_to_scc.exceptions import (
     NoMeasurementsInTimePeriod,
     TimeOutsideFile,
@@ -196,10 +196,7 @@ def create_scc_calibration_netcdf(
 ) -> Tuple[str, Path]:
     """
     From a PollyXT netCDF file, create the corresponding calibration SCC file.
-    Calibration times are:
-    - 02:31 to 02:41
-    - 17:31 to 17:41
-    - 21:31 to 21:41
+    Calibration only occures when `depol_cal_angle` is not equal to the default state value.
     Take care to create the `PollyXTFile` with these intervals.
 
     Parameters:
@@ -227,16 +224,36 @@ def create_scc_calibration_netcdf(
         raise ValueError(f"Unknown wavelength {wavelength}")
     nc = Dataset(output_filename, "w")
 
+    # Find start/end indices for the +45 and -45 degree calibration cycles in Polly file
+    idx = list(np.where(np.diff(pf.depol_cal_angle))[0])
+    start_positive = 2
+    idx = list(filter(lambda x: x >= start_positive + 4, idx))
+    end_positive = idx[0]
+    positive_length = end_positive - start_positive
+
+    start_negative = idx[0] + 3
+    idx = list(filter(lambda x: x >= start_negative + 4, idx))
+    end_negative = pf.depol_cal_angle.shape[0] - 3
+    negative_length = end_negative - start_negative
+
+    if positive_length != negative_length:
+        raise ValueError(
+            f"Positive and negative calibration cycles have different lengths: {positive_length} vs {negative_length}"
+        )
+
     # Create Dimensions. (mandatory)
     nc.createDimension("points", np.size(pf.raw_signal, axis=1))
     nc.createDimension("channels", 4)
-    nc.createDimension("time", 3)
+    nc.createDimension("time", positive_length)
     nc.createDimension("nb_of_time_scales", 1)
     nc.createDimension("scan_angles", 1)
 
     # Create Global Attributes. (mandatory)
-    nc.RawData_Start_Date = pf.start_date.strftime("%Y%m%d")
-    nc.RawData_Start_Time_UT = pf.start_date.strftime("%H%M%S")
+    # Move start date a couple of profiles forward to accomodate the fact that we skip
+    # some profiles at the beginning of the file.
+    start_date = pf.start_date + timedelta(seconds=(start_positive * 30))
+    nc.RawData_Start_Date = start_date.strftime("%Y%m%d")
+    nc.RawData_Start_Time_UT = start_date.strftime("%H%M%S")
     nc.RawData_Stop_Time_UT = pf.end_date.strftime("%H%M%S")
 
     # Create Global Attributes (optional)
@@ -292,17 +309,19 @@ def create_scc_calibration_netcdf(
         "Temperature_at_Lidar_Station", "f8", dimensions=(), zlib=True
     )
 
-    # define measurement_cycles
-    start_first_measurement = 0
-    stop_first_measurement = 12
-
     # Fill Variables with Data. (mandatory)
+    raw_data_start_time[:] = (
+        pf.measurement_time[start_positive: end_positive, 1]
+        - pf.measurement_time[start_positive, 1]
+    )
+    raw_data_stop_time[:] = (
+        pf.measurement_time[start_negative: end_negative, 1]
+        - pf.measurement_time[start_positive, 1]
+    )
     id_timescale[:] = np.array([0, 0, 0, 0])
     laser_pointing_angle[:] = 5
     laser_pointing_angle_of_profiles[:, :] = 0.0
-    laser_shots[0, :] = np.array([600, 600, 600, 600])
-    laser_shots[1, :] = np.array([600, 600, 600, 600])
-    laser_shots[2, :] = np.array([600, 600, 600, 600])
+    laser_shots[:] = 600
     background_low[:] = np.array([0, 0, 0, 0])
     background_high[:] = np.array([249, 249, 249, 249])
     molecular_calc[:] = 0
@@ -313,17 +332,23 @@ def create_scc_calibration_netcdf(
 
     # Define total and cross channels IDs from Polly
     if wavelength == Wavelength.NM_355:
-        total_channel = location.total_channel_355_nm
-        cross_channel = location.cross_channel_355_nm
-        channel_id[:] = np.array(location.calibration_355nm_channel_ids)
+        total_channel_idx = location.total_channel_355_nm_idx
+        cross_channel_idx = location.cross_channel_355_nm_idx
+        channel_id[:] = np.array(
+            location.calibration_355nm_total_channel_ids
+            + location.calibration_355nm_cross_channel_ids
+        )
         nc.Measurement_ID = measurement_id + "35"
         nc.X_PollyXTPipelines_Configuration_ID = (
             location.calibration_configuration_355nm
         )
     elif wavelength == Wavelength.NM_532:
-        total_channel = location.total_channel_532_nm
-        cross_channel = location.cross_channel_532_nm
-        channel_id[:] = np.array(location.calibration_532nm_channel_ids)
+        total_channel_idx = location.total_channel_532_nm_idx
+        cross_channel_idx = location.cross_channel_532_nm_idx
+        channel_id[:] = np.array(
+            location.calibration_532nm_total_channel_ids
+            + location.calibration_532nm_cross_channel_ids
+        )
         nc.Measurement_ID = measurement_id + "53"
         nc.X_PollyXTPipelines_Configuration_ID = (
             location.calibration_configuration_532nm
@@ -331,25 +356,23 @@ def create_scc_calibration_netcdf(
     else:
         raise ValueError(f"Unknown wavelength {wavelength}")
 
-    # Copy calibration cycles
-    for meas_cycle in range(0, 3, 1):
-        laser_shots[meas_cycle, :] = np.array([600, 600, 600, 600])
-
-        raw_data_start_time[meas_cycle, 0] = start_first_measurement + meas_cycle
-        raw_data_stop_time[meas_cycle, 0] = stop_first_measurement + meas_cycle
-
-        raw_lidar_data[meas_cycle, 0, :] = pf.raw_signal_swap[
-            start_first_measurement + meas_cycle, cross_channel, :
-        ]
-        raw_lidar_data[meas_cycle, 1, :] = pf.raw_signal_swap[
-            start_first_measurement + meas_cycle, total_channel, :
-        ]
-        raw_lidar_data[meas_cycle, 2, :] = pf.raw_signal_swap[
-            stop_first_measurement + meas_cycle, cross_channel, :
-        ]
-        raw_lidar_data[meas_cycle, 3, :] = pf.raw_signal_swap[
-            stop_first_measurement + meas_cycle, total_channel, :
-        ]
+    raw_lidar_data[:] = 0
+    # Total channel, +45°
+    raw_lidar_data[:, 0, :] = pf.raw_signal_swap[
+        start_positive:end_positive, total_channel_idx, :
+    ]
+    # Cross channel, +45°
+    raw_lidar_data[:, 2, :] = pf.raw_signal_swap[
+        start_positive:end_positive, cross_channel_idx, :
+    ]
+    # Total channel, -45°
+    raw_lidar_data[:, 1, :] = pf.raw_signal_swap[
+        start_negative:end_negative, total_channel_idx, :
+    ]
+    # Cross channel, -45°
+    raw_lidar_data[:, 3, :] = pf.raw_signal_swap[
+        start_negative:end_negative, cross_channel_idx, :
+    ]
 
     # Close the netCDF file.
     nc.close()
